import sys

# To run with python 3: Move sumo from Program Files(x86)/DLR/ to this location, then run and fix the one sytax error.
from conf.settings_traci import TRACI_PATH
sys.path.insert(0, TRACI_PATH)

import traci
from traci._vehicle import VehicleDomain


class DumbTraci:
    """ Run the traci simulator with stupid routing. """

    def __init__(self, gui, net) -> None:
        """ Setup connection with traci. """

        self.net = net

        # compose the command line to start SUMO
        if gui:
            sumo_binary = "sumo-gui"
        else:
            sumo_binary = "sumo"
        sumo_cmd = [sumo_binary, "-c", "sumomodel/tetrax/tetrax.sumo.cfg", "--no-step-log", "true"]

        # Start simulation and connect to it
        traci.start(sumo_cmd)

    def run(self, start, start_ordered) -> None:

        # weird traci api
        vehicles: VehicleDomain = traci.vehicle

        time: int = 0  # log time steps

        # cars from node 1 take route1, from node 3 take route3
        for node in self.net.net.getNodes():
            if node.getID() == 'leiden':
                nr_cars: int = start[node]
                for i in range(nr_cars):
                    vehicles.add(f'veh1_{i}', routeID='route-lei2', typeID='Car')
            elif node.getID() == 'amersfoort':
                nr_cars: int = start[node]
                for i in range(nr_cars):
                    vehicles.add(f'veh2_{i}', routeID='route-amf2', typeID='Car')
            elif node.getID() == 'utrecht':
                nr_cars: int = start[node]
                for i in range(nr_cars):
                    vehicles.add(f'veh3_{i}', routeID='route-utr3', typeID='Car')
            elif node.getID() == 'denhaag':
                nr_cars: int = start[node]
                for i in range(nr_cars):
                    vehicles.add(f'veh4_{i}', routeID='route-dh1', typeID='Car')
            elif node.getID() == 'eindhoven':
                nr_cars: int = start[node]
                for i in range(nr_cars):
                    vehicles.add(f'veh5_{i}', routeID='route-ehv1', typeID='Car')

        # First run a step in order to get the car driving
        # otherwise the check for cars left fails immediately
        traci.simulationStep()

        # while there are cars driving
        while vehicles.getIDList():
            traci.simulationStep()
            time += 1

        # traci.close()  # just let it crash, don't close so we can run again

        return time
